@@ -264,19 +264,22 @@ def justify(s,width):
     # вернуть строку в utf8 если она пришла в utf8
     return s.encode('utf-8')
 
-def runOsCommand(cmd, inStr=None, ret_first=None):
+def runOsCommand(cmd, inStr=None, ret_first=None, env_dict=None):
     """Выполняет внешнюю программу
 
     Параметры:
     cmd            внешняя программа
     inStr          данные передаваемые программе на страндартный вход.
     ret_first      вернуть только первую строку
+    env_dict       словарь переменных окружения
     Возвращаемые параметры:
     строка/строки которую выведет внешняя программа
+    Возвращает код возврата, stdout+stderr
     """
     pipe = subprocess.Popen(cmd, stdin=subprocess.PIPE,
                             stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE,
+                            env=env_dict,
                             close_fds=True,
                             shell=True)
     fout, fin, ferr = (pipe.stdout, pipe.stdin, pipe.stderr)
@@ -284,19 +287,19 @@ def runOsCommand(cmd, inStr=None, ret_first=None):
     if inStr:
         fin.write(inStr)
     fin.close()
+    # Код возврата
+    retcode = pipe.wait()
     res = fout.readlines()
     fout.close()
     res += ferr.readlines()
     ferr.close()
     if res:
-        if len(res) > 1:
-            if ret_first:
-                return res[0]
-            else:
-                return res
+        if len(res) == 1 or ret_first:
+            return retcode, res[0].strip()
         else:
-            return res[0].strip()
-
+            return retcode, res
+    return retcode, None
+ 
 
 def genpassword(passlen=9):
     '''Вернуть случайный пассворд указанной длины
@@ -326,7 +329,7 @@ def getpathenv():
             if os.path.exists(dirname) and dirname not in lpath:
                 npath.append(dirname)
         lpath=npath+lpath
-        return "PATH="+":".join(lpath)+" && "
+        return ":".join(lpath)
 
 #класс для работы с установленными пакетами
 class pakages:
